<?php

namespace SlotDb\Cli\Command\Slot;

use SlotDb\Client\SlotDbClient;
use Symfony\Component\Console\Attribute\AsCommand;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputArgument;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

#[AsCommand(name:"slot:create", description:"Create a new slot")]
class SlotCreateCommand extends Command
{
    public function __construct(
        private readonly SlotDbClient $client
    )
    {
        parent::__construct();
    }

    protected function configure()
    {
        $this
            ->addOption("name", "N", InputOption::VALUE_REQUIRED, "Set slot name")
            ->addArgument("slot", InputArgument::REQUIRED, "Slot ID")
            ->addArgument("properties", InputArgument::IS_ARRAY, "Properties to assign to the slot")
            ;
    }

    protected function execute(InputInterface $input, OutputInterface $output): int
    {

        $slotId = $input->getArgument("slot");
        $slotName = $input->getOption("name") ?? $slotId;

        $props = [];
        foreach ($input->getArgument("properties") as $prop) {
            if (!str_contains($prop, '=')) {
                $output->writeln("<error>Invalid property \"{$prop}\", should be in the form of key=value.</>");
                return self::INVALID;
            }
            [$k, $v] = explode("=", $prop, 2);
            $props[$k] = match ($v) {
                'true','false','null' => json_decode($v),
                default => json_decode($v) ?? $v,
            };
        }

        $slot = $this->client->createSlot($slotId, $slotName, $props);

        var_dump($slot);

        return self::SUCCESS;
    }
}
